import { ColorPaletteConfig } from '@graphpolaris/shared/data-access/store';
import { ThemeOptions } from '@mui/material/styles';
import Color from 'color';

/** Maps our color palette config (stored in redux) to the mui 5 theme format */
export default function MapColorsConfigToMuiTheme(
  colorsConfig: ColorPaletteConfig
): ThemeOptions {
  return {
    palette: {
      mode: colorsConfig.darkMode ? 'dark' : 'light',

      ...(colorsConfig.darkMode
        ? {
            primary: colorsConfig.darkPalette.primary,
            secondary: colorsConfig.darkPalette.secondary,
            dataPointColors: colorsConfig.darkPalette.custom.dataPointColors,
            queryBuilder: {
              text: colorsConfig.darkPalette.custom.queryBuilder.text,
              entity: {
                background:
                  colorsConfig.darkPalette.custom.queryBuilder.entity
                    .background,
                lighterbg: Color(
                  colorsConfig.darkPalette.custom.queryBuilder.entity.background
                )
                  .lighten(0.2)
                  .toString(),
              },
              relation: {
                background:
                  colorsConfig.darkPalette.custom.queryBuilder.relation
                    .background,
                lighterbg: Color(
                  colorsConfig.darkPalette.custom.queryBuilder.relation
                    .background
                )
                  .lighten(0.2)
                  .toString(),
              },
              attribute: {
                background:
                  colorsConfig.darkPalette.custom.queryBuilder.attribute
                    .background,
              },
            },
          }
        : {
            primary: colorsConfig.lightPalette.primary,
            secondary: colorsConfig.lightPalette.secondary,
            dataPointColors: colorsConfig.lightPalette.custom.dataPointColors,
            queryBuilder: {
              text: colorsConfig.lightPalette.custom.queryBuilder.text,
              entity: {
                background:
                  colorsConfig.lightPalette.custom.queryBuilder.entity
                    .background,
                lighterbg: Color(
                  colorsConfig.lightPalette.custom.queryBuilder.entity
                    .background
                )
                  .lighten(0.2)
                  .toString(),
              },
              relation: {
                background:
                  colorsConfig.lightPalette.custom.queryBuilder.relation
                    .background,
                lighterbg: Color(
                  colorsConfig.lightPalette.custom.queryBuilder.relation
                    .background
                )
                  .lighten(0.2)
                  .toString(),
              },
              attribute: {
                background:
                  colorsConfig.lightPalette.custom.queryBuilder.attribute
                    .background,
              },
            },
          }),
    },
  };
}
